@@ -17,7 +17,7 @@ if [ "$VCS" = "true" ]
 then
     SEARDUINO_PATH=$(pwd)
 else
-    SEARDUINO_PATH=/opt
+    SEARDUINO_PATH=/tmp/hesa/TMP_INSTALL3
 fi
 
 
