@@ -19,10 +19,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-export PATH=/opt/bin:${PATH}
-export LD_LIBRARY_PATH=/opt/lib
-export PYTHONPATH=/opt/lib
-export DYLD_LIBRARY_PATH=/opt/lib
+export PATH=/tmp/hesa/TMP_INSTALL3/bin:${PATH}
+export LD_LIBRARY_PATH=/tmp/hesa/TMP_INSTALL3/lib
+export PYTHONPATH=/tmp/hesa/TMP_INSTALL3/lib
+export DYLD_LIBRARY_PATH=/tmp/hesa/TMP_INSTALL3/lib
 
-/opt/bin/pardon.py $*
+/tmp/hesa/TMP_INSTALL3/bin/pardon.py $*
 
